@@ -1825,7 +1825,7 @@ class TestStudentT(BaseTestDistributionRandom):
 
 class TestHalfStudentT(BaseTestDistributionRandom):
     def halfstudentt_rng_fn(self, df, loc, scale, size, rng):
-        return np.abs(st.t.rvs(df=df, loc=loc, scale=scale, size=size))
+        return np.abs(st.t.rvs(df=df, loc=loc, scale=scale, size=size, random_state=rng))
 
     pymc_dist = pm.HalfStudentT
     pymc_dist_params = {"nu": 5.0, "sigma": 2.0}
